<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Controllers\Middleware;

use App\Services\CustomerService;
use App\Services\ThirdPlatform\ZhenKhService;
use Closure;
use Illuminate\Auth\Access\AuthorizationException;
use Illuminate\Contracts\Auth\Factory as Auth;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Support\Traits\Helpers;
use Symfony\Component\HttpKernel\Exception\UnauthorizedHttpException;


class Authenticate
{
    use Helpers;
    /**
     * The authentication guard factory instance.
     *
     * @var Auth
     */
    protected $auth;

    /**
     * Create a new middleware instance.
     *
     * @param  Auth  $auth
     */
    public function __construct(Auth $auth)
    {
        $this->auth = $auth;
    }

    /**
     * Handle an incoming request.
     *
     * @param  Request  $request
     * @param  Closure  $next
     * @param  string|null  $guard
     * @return mixed
     *
     * @throws AuthorizationException
     */
    public function handle($request, Closure $next, $guard = null)
    {
        if(!$request->header('authorization')){
            return Response::fail('token 不存在!',500,'');
        }
        $token = trim(str_ireplace('bearer', '', $request->header('authorization')));
        try{
            $decodeToken = $this->decodeToken($token);
            if(empty($decodeToken) || (!is_array($decodeToken) && !$decodeToken['hash'])){
                return Response::fail('客户token无效',500,'');
            }
        }catch(\Throwable $exception){
            return Response::fail($exception->getMessage(),500,'');
        }

        $params = $request->all();
        // 内部平台调用
        if(isset($params['platform']) && !empty($params['platform'])){
            switch($params['platform']){
                case 'zkh' : $platformToken = app(ZhenKhService::class)->apiService->getPlatformInfo('platform_token');break;
            }
            if(empty($platformToken) || $decodeToken['hash'] !== $platformToken){
                throw new UnauthorizedHttpException('JWTAuth','无效的平台token');
            }
        }
        else{
            if($decodeToken['expire'] < time())
            {
                return Response::fail('身份验证失效，请重新登录',500,'');
            }
            $customerService = app(CustomerService::class);
            try{
              $customer = $customerService->getCustomerInfoByToken($decodeToken['hash']);
              if($customer['status'] == 0){
                  return Response::fail('用户已被禁用，请联系管理员',500,'');
              }
              $request->attributes->add(['customer_code' => $customer['cus_number']]);
            }catch(\Throwable $exception){
                return Response::fail('客户token无效',500,'');
            }
        }

        return $next($request);
    }
}
