<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Repositories\Eloquent;

use App\Repositories\Presenters\Presenter;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Pagination\LengthAwarePaginator;
use Prettus\Repository\Eloquent\BaseRepository as BaseRepositoryEloquent;

abstract class BaseRepository extends BaseRepositoryEloquent
{
    /**
     * @var Presenter
     */
    protected $presenter;

    /**
     * Retrieve all data of repository, simple paginated.
     *
     * @param null|int $limit
     * @param array $columns
     * @return mixed
     */
    public function cursorPaginate($limit = null, $columns = ['*'])
    {
        $this->applyCriteria();
        $this->applyScope();
        $limit = is_null($limit) ? config('repository.pagination.limit', 15) : (int) $limit;

        $results = $this->model->select($columns)->limit($limit)->get();

        if ($this->model instanceof Builder) {
            $primaryKey = $this->model->getModel()->getKeyName();
        } else {
            $primaryKey = $this->model->getKeyName();
        }

        $count = $results->count();
        $next = $count === $limit ? optional($results->last())->{$primaryKey} : null;
        $this->resetModel();
        $dataResult = $this->parserResult($results);

        $page = request('page')?:1;
        //每页的条数
        $perPage = $limit;
        //计算每页分页的初始位置
        $offset = ($page * $perPage) - $perPage;
        //实例化Paginator类，(删掉上一步的count($video_list)参数即可 )并传入对应的参数
        $data = new LengthAwarePaginator(array_slice($dataResult, $offset, $perPage, true), count($dataResult), $perPage, $page);
        return $data;
    }


    public function customPaginate($limit = null, $columns = ['*'])
    {
        $paginateResult = $this->paginate($limit,$columns);

        $dataList = [];
        // 将model对象转换城数组
        foreach($paginateResult->items() as $data){
            $dataList[] = $data->toArray();
        }

        $returnRecord = [];
        $returnRecord['data'] = $dataList;
        $returnRecord['current_page'] = $paginateResult->currentPage();
        $returnRecord['total'] = $paginateResult->total();
        $returnRecord['page'] = $paginateResult->currentPage() + 1;
        if($returnRecord['page'] >= $paginateResult->lastPage()){
           $returnRecord['page'] = $paginateResult->lastPage();
        }

        return $returnRecord;
    }

    protected function getConnectionName()
    {
        return app($this->model())->getConnectionName();
    }

    protected function getTableName()
    {
        return app($this->model())->getTable();
    }
}
