<?php

namespace App\Rhawn\Repositories\Eloquent;

use App\Rhawn\Repositories\Contracts\BhuaBrandsRepository;
use App\Rhawn\Repositories\Contracts\BhuaSordersRepository;
use App\Rhawn\Repositories\Models\BhuaSorders;
use Illuminate\Support\Facades\DB;
use Prettus\Validator\Contracts\ValidatorInterface;

/**
 * Class UserRepositoryEloquent.
 */
class BhuaSordersRepositoryEloquent extends BaseRepository implements BhuaSordersRepository
{
    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return BhuaSorders::class;
    }

    /**
     * 返回指定订单编号的订单信息
     * @param $order_no
     * @return mixed
     */
    public function getSorderFromOrderNo($orderNo)
    {
        $where = [
            'so_no' => $orderNo
        ];
        return $this->findWhere($where)->first();
    }

    public function getSorderFromOrderCusPo($orderNo)
    {
        $where = [
            'so_cus_po' => $orderNo
        ];
        return $this->findWhere($where)->first();
    }

    /**
     * 获取订单详情
     * @param $orderNo
     * @return mixed
     */
    public function getSorderItemsFromOrderNo($orderNo){
        $soItems = $this
            ->join('soitems','soitems.so_id','sorders.so_id')
            ->where('sorders.so_no',$orderNo)->get();
        if($soItems){
            return $soItems->toArray();
        }
        return null;
    }

    /**
     * 获取订单相关信息（包括，产品，客户，品牌等）
     * @param $so_id
     * @return mixed
     */
    public function getSorderDetailFromOrderId($so_id)
    {
        $sOrderInfo = $this
            ->join('customers','sorders.cus_id','customers.cus_id')
            ->where('sorders.so_id',$so_id)
            ->get();
        if(!$sOrderInfo){
            return null;
        }
        $sOrderInfo = current($sOrderInfo->toArray());

        $items = DB::connection($this->getConnectionName())->table('soitems')
            ->join('products','soitems.p_id','products.p_id')
            ->join('chemicals','products.c_id','chemicals.c_id')
            ->join('brands','products.b_id','brands.b_id')
            ->where('soitems.so_id',$so_id)
            ->get();

        if(!$items){
            $sOrderInfo['items'] = [];
        }
        $sOrderInfo['items'] = $items->toArray();

        return $sOrderInfo;
    }

    /**
     * 获取客户订单
     * @param $userId
     * @param $pageSize
     * @param $offset
     * @return array|null
     */
    public function getOrdersListThroughtUserId($userId,$offset,$limit)
    {
        $sOrderInfo = DB::connection($this->getConnectionName())->table($this->getTableName())
            ->join('customers','customers.cus_id','sorders.cus_id')
            ->where('sorders.cus_id',$userId)
            ->offset($offset)
            ->limit($limit)
            ->get();
        if($sOrderInfo){
            return $sOrderInfo->toArray();
        }
        return null;
    }

    /**
     * 获取客户订单详情
     * @param $cusId
     * @param $orderId
     * @return null
     */
    public function getCustomerOrderItemsByOrderId($cusId,$orderId)
    {
        $sOrderInfo = $this
            ->join('customers','sorders.cus_id','customers.cus_id')
            ->where('sorders.so_id',$orderId)
            ->where('sorders.cus_id',$cusId)
            ->first();
        if(!$sOrderInfo){
            return null;
        }
        $sOrderInfo = $sOrderInfo->toArray();

        $itemRepository = app(BhuaSoitemsRepositoryEloquent::class);
        $items = $itemRepository->getSorderItemsDetailFromOrderId($sOrderInfo['so_id']);
        $sOrderInfo['items'] = [];
        if($items){
            $sOrderInfo['items'] = $items;
        }

        return $sOrderInfo;
    }

    public function getOrderDispatch($orderNumber)
    {
        $dpModel = $this->join('dispatch','dispatch.so_id','sorders.so_id')
            ->join('dpdetail','dpdetail.dp_id','dispatch.dp_id');
        if(is_array($orderNumber)){
            $dpModel->whereIn('sorders.so_no',$orderNumber);
        }else{
            $dpModel->where('sorders.so_no',$orderNumber);
        }
        $dpdetail = $dpModel->get();
        if($dpdetail){
            return $dpdetail->toArray();
        }
        return null;
    }

}
