<?php

namespace App\Rhawn\Repositories\Eloquent;

use App\Rhawn\Repositories\Contracts\RhawnSoitemsRepository;
use App\Rhawn\Repositories\Contracts\RhawnSordersRepository;
use App\Rhawn\Repositories\Models\RhawnSoitems;
use Prettus\Validator\Contracts\ValidatorInterface;

/**
 * Class UserRepositoryEloquent.
 */
class RhawnSoitemsRepositoryEloquent extends BaseRepository implements RhawnSoitemsRepository
{
    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return RhawnSoitems::class;
    }

    /**
     * 获取订单详情
     * @param $orderId
     * @return \Illuminate\Database\Eloquent\Builder[]|\Illuminate\Database\Eloquent\Collection
     */
    public function getSorderItemsDetailFromOrderId($orderId)
    {
        $order = app(RhawnSordersRepository::class)->find($orderId);
        if(!$order){
            throw new \LogicException('该订单不存在!',500);
        }

        //查询订单的详情
        $soItems = RhawnSoitems::query()
            ->join('products','soitems.p_id','products.p_id')
            ->join('chemicals','products.c_id','chemicals.c_id')
            ->join('brands','products.b_id','brands.b_id')
            ->where('soitems.so_id',$order->so_id)->get();

        if($soItems){
            return $soItems->toArray();
        }
        return null;
    }

    public function getSorderItemsDetailFromItemId($itemId,$pid=null)
    {
        //查询订单的详情
        $soItems = RhawnSoitems::query()
            ->join('sorders','sorders.so_id','soitems.so_id')
            ->join('products','soitems.p_id','products.p_id')
            ->join('chemicals','products.c_id','chemicals.c_id')
            ->join('brands','products.b_id','brands.b_id')
            ->where('soitems.si_id',$itemId);
        if(!is_null($pid)){
            $soItems = $soItems->where('soitems.p_id',$pid);
        }
        $soItems = $soItems->get();
        if($soItems){
            return $soItems->toArray();
        }

        return null;
    }

    /**
     * 根据si_id获取订单明细项
     * @param $si_id
     * @return \Illuminate\Database\Eloquent\Builder[]|\Illuminate\Database\Eloquent\Collection
     */
    public function getSorderItemFromItemId($si_id)
    {
        $item = $this->find($si_id);
        if(!$item){
            throw new \LogicException('该订单项不存在!',500);
        }

        //查询订单的详情
        $soModel = RhawnSoitems::query()
            ->join('products','soitems.p_id','products.p_id')
            ->join('chemicals','chemicals.c_id','products.c_id');
        if(is_array($si_id)){
            $soModel->whereIn('soitems.si_id',$si_id);
        }else{
            $soModel->where('soitems.si_id',$si_id);
        }
        $soItems = $soModel->get();
        if($soItems){
            return $soItems->toArray();
        }

        return null;
    }

    public function getOrderItemsStockFromItemIds($id)
    {
        if(!is_array($id)){
            $item = $this->find($id);
            $id = (array)$id;
        }else{
            $item = RhawnSoitems::query()->whereIn('si_id',$id)->get();
        }
        if(!$item){
            throw new \LogicException('该订单项不存在!',500);
        }

        //查询订单的详情
        $soItemStock = RhawnSoitems::query()
            ->join('dpdetail','dpdetail.si_id','soitems.si_id')
            ->join('pstock','pstock.pstk_id','dpdetail.pstk_id')
            ->join('products','soitems.p_id','products.p_id')
            ->whereIn('soitems.si_id',$id)
            ->where('si_if_cancel',0)
            //->where('dpdetail.dpd_invoiced','=',0)
            ->get();
        if($soItemStock){
            return $soItemStock->toArray();
        }

        return null;
    }
}
