<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\Api;

use App\Repositories\Transformers\Rhawn\OrderDetailTransformer;
use App\Rhawn\Services\BhuaCustomerService;
use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;

class BhuaOrdersService
{
    public function __construct(\App\Rhawn\Services\BhuaOrdersService $bhuaOrdersService)
    {
        $this->bhuaOrdersService = $bhuaOrdersService;
        $this->bhuaCustomerService = app(BhuaCustomerService::class);
    }

    /**
     * 新增订单
     * @param $requestParams
     */
    public function createNewCustomerOrders($requestParams)
    {
        try{
            $customer = $this->bhuaCustomerService->checkCustomerExist($requestParams['customer_code']);

            if(!isset($requestParams['so_ca_county'])){
                $requestParams['so_ca_county'] = '';
            }

            $orderItems = $this->bhuaOrdersService->getCustomerOrderItems($customer['cus_no'],$requestParams['items']);
            if(!$orderItems){
                throw new \Exception('货号无法匹配',500);
            }

            $express = $this->bhuaOrdersService->getExpress(
                $orderItems['weight'],$requestParams['so_ca_province'],$orderItems['total'],0,0
            );

            $order = $this->bhuaOrdersService->bhuaSorderRepository->getSorderFromOrderCusPo($requestParams['so_cus_po']);
            if($order){
                throw new \Exception('不能重复创建新订单!',500);
            }

            $data = [];
            $data['sorders']['cus_id'] = $customer['cus_id'];
            $data['sorders']['so_cus_po'] = $requestParams['so_cus_po'];
            $data['sorders']['so_ca_name'] = $requestParams['so_ca_name'];
            $data['sorders']['so_ca_mobile'] = $requestParams['so_ca_mobile'];
            $data['sorders']['so_ca_phone'] = !isset($requestParams['so_ca_phone']) ? '' : $requestParams['so_ca_phone'];
            $data['sorders']['so_ca_province'] = $requestParams['so_ca_province'];
            $data['sorders']['so_ca_city'] = $requestParams['so_ca_city'];
            $data['sorders']['so_ca_county'] = $requestParams['so_ca_county'];
            $data['sorders']['so_ca_street'] = $requestParams['so_ca_street'];

            //得到收票地址
            $cusiaddrs_arr = $this->bhuaCustomerService->bhuaCustomerRepository->getCustomerAddressByCusCode($customer['cus_no']);
            $cusinvoice_arr = $this->bhuaCustomerService->bhuaCustomerRepository->getCustomerInvoiceByCusCode($customer['cus_no']);

            if(!$cusiaddrs_arr){
               throw new \Exception('请至会员中心设置收票地址',500);
            }
            if(!$cusinvoice_arr){
                throw new \Exception('请至会员中心设置发票信息',500);
            }

            $cusiaddrs_arr = current($cusiaddrs_arr);
            $cusinvoice_arr = current($cusinvoice_arr);

            $data['sorders']['so_cia_name'] = $cusiaddrs_arr['cia_name'];
            $data['sorders']['so_cia_mobile'] = $cusiaddrs_arr['cia_mobile'];
            $data['sorders']['so_cia_phone'] = $cusiaddrs_arr['cia_phone'];
            $data['sorders']['so_cia_province'] = $cusiaddrs_arr['cia_province'];
            $data['sorders']['so_cia_city'] = $cusiaddrs_arr['cia_city'];
            $data['sorders']['so_cia_county'] = $cusiaddrs_arr['cia_county'];
            $data['sorders']['so_cia_street'] = $cusiaddrs_arr['cia_street'];

            $data['sorders']['so_cia_name'] = $cusiaddrs_arr['cia_name'];
            $data['sorders']['so_ci_type'] = $cusinvoice_arr['ci_type'];
            $data['sorders']['so_ci_title'] = $cusinvoice_arr['ci_title'];
            $data['sorders']['so_ci_vatno'] = $cusinvoice_arr['ci_vatno'];
            $data['sorders']['so_ci_bank'] = $cusinvoice_arr['ci_bank'];
            $data['sorders']['so_ci_bknum'] = $cusinvoice_arr['ci_bknum'];
            $data['sorders']['so_ci_addr'] = $cusinvoice_arr['ci_addr'];
            $data['sorders']['so_ci_phone'] = $cusinvoice_arr['ci_phone'];
            $data['sorders']['so_standard'] = 0;

            $data['sorders']['so_creater'] = $customer['cus_id'];

            if(!isset($requestParams['so_note'])){
                $requestParams['so_note'] = '';
            }
            $data['sorders']['so_note'] = $requestParams['so_note'];
            $data['sorders']['so_send_note'] = $customer['cus_send_note'];
            $data['sorders']['so_ci_method'] = 1;
            $data['sorders']['so_total'] = $orderItems['total'] + $express;
            $data['express'] = $express;
            $data['v_id'] = '';
            $data['soitems'] = [];
            foreach($orderItems['rows'] as $k => $v){
                $soitem = [];
                $soitem['p_id'] = $v['product_info']['p_id'];
                $soitem['si_price'] = $v['product_info']['p_price'];
                $soitem['si_discount'] = $v['product_info']['p_discount'];
                $soitem['si_num'] = $v['num'];
                $soitem['si_amount'] = $v['product_info']['p_discount'] * $v['num'];
                $soitem['si_p_tod'] = $v['product_info']['p_tod'];
                $soitem['si_vamount'] = 0;

                array_push($data['soitems'],$soitem);
            }

            $orderId = $this->bhuaOrdersService->createOrders($data);
            if($orderId){
                $orderDetail = $this->bhuaOrdersService->getCustomerOrderItemsByOrderId($customer['cus_id'],$orderId);
                $orderDetail = app(OrderDetailTransformer::class)->transform([$orderDetail]);
                return current($orderDetail);
            }
            return null;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':createNewCustomerOrders','error');
            throw $exception;
        }
    }
}
