<?php

namespace App\Services\Api;

use App\Repositories\Transformers\Rhawn\Bhua\BrandsTransformer;
use App\Rhawn\Services\BhuaCustomerService;
use App\Rhawn\Services\BhuaProductService;
use App\Rhawn\Services\RhawnCustomerService;
use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;

class BhuaProductsService
{
    public function __construct()
    {
        $this->bhuaProductService = app(BhuaProductService::class);
        $this->bhuaCustomerService = app(BhuaCustomerService::class);
    }

    public function getAllBrands($requestParams)
    {
        $offset = !isset($requestParams['page_size']) || empty($requestParams['page_size']) ? 2000 : $requestParams['page_size'];
        if($offset > 100){
            $offset = 100;
        }
        $pageNo = !isset($requestParams['page_no']) || empty($requestParams['page_no']) ? 1 : $requestParams['page_no'];
        $limit = $pageNo == 1 ? 0 : $pageNo * $offset;
        try{
            $where = [];
            $brandsList = $this->bhuaProductService->getBrandsList($where,$offset,$limit);
            $brandsTotal = 0;
            if($brandsList){
                $brandsList = app(BrandsTransformer::class)->transform($brandsList);
                $brandsTotal = $this->bhuaProductService->brandsRepository->count($where);
            }

            $dataReturn = [];
            $dataReturn['data'] = $brandsList;
            $dataReturn['total_page'] = ceil($brandsTotal / $offset);
            $dataReturn['page_no'] = $pageNo;

            return $dataReturn;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':getAllBrands','error');
            throw $exception;
        }
    }

}
