<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\Api;

use App\Repositories\Eloquent\RhawnSordersRepositoryEloquent;
use App\Repositories\Transformers\Rhawn\OrderDetailTransformer;
use App\Repositories\Transformers\Rhawn\OrdersDispatchTransformer;
use App\Rhawn\Repositories\Eloquent\RhawnCustomerRepositoryEloquent;
use App\Rhawn\Services\RhawnCustomerService;
use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;
use mysql_xdevapi\Exception;

class RhawnOrdersService
{
    public function __construct(\App\Rhawn\Services\RhawnOrdersService $rhawnOrdersService)
    {
        $this->rhawnOrdersService = $rhawnOrdersService;
        $this->rhawnCustomerService = app(RhawnCustomerService::class);
    }

    /**
     * 获取罗恩订单列表
     * @param $requestParams
     */
    public function getCustomerRhawnOrdersList($requestParams)
    {
        try{
            $customer = $this->rhawnCustomerService->checkCustomerExist($requestParams['customer_code']);

            $offset = !isset($requestParams['page_size']) || empty($requestParams['page_size']) ? 100 : $requestParams['page_size'];
            if($offset > 100){
                $offset = 100;
            }
            $pageNo = !isset($requestParams['page_no']) || empty($requestParams['page_no']) ? 1 : $requestParams['page_no'];
            $limit = $pageNo == 1 ? 0 : $pageNo * $offset;

            $rhawnOrderRepository = app(RhawnSordersRepositoryEloquent::class);
            $orderList = $rhawnOrderRepository->getCustomerOrderList($customer['cus_id'],$limit,$offset);

            //获取订单量总数
            $total = $rhawnOrderRepository->orderTotalByCusId($customer['cus_id']);

            $dataReturn = [];
            $dataReturn['data'] = $orderList;
            $dataReturn['total_page'] = ceil($total / $offset);
            $dataReturn['page_no'] = $pageNo;

            return $dataReturn;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':getCustomerRhawnOrdersList','error');
            throw $exception;
        }
    }

    /**
     * 获取客户订单详情
     * @param $requestParams
     */
    public function getCustomerOrderDetail($requestParams)
    {
        try{
            $customer = $this->rhawnCustomerService->checkCustomerExist($requestParams['customer_code']);

            $order = $this->rhawnOrdersService->getSordersByOrderNo($requestParams['order_number']);
            if(!$order){
                throw new \Exception('订单编号不存在',500);
            }
            $orderDetail = $this->rhawnOrdersService->getCustomerOrderItemsByOrderId($customer['cus_id'],$order['so_id']);
            $orderDetail = app(OrderDetailTransformer::class)->transform([$orderDetail]);
            return current($orderDetail);

        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':getCustomerOrderDetail','error');
            throw $exception;
        }
    }

    /**
     * 新增订单
     * @param $requestParams
     */
    public function createNewCustomerOrders($requestParams)
    {
        try{
            $customer = $this->rhawnCustomerService->checkCustomerExist($requestParams['customer_code']);

            if(!isset($requestParams['so_ca_county'])){
                $requestParams['so_ca_county'] = '';
            }

            $orderItems = $this->rhawnOrdersService->getCustomerOrderItems($customer['cus_no'],$requestParams['items']);
            if(!$orderItems){
                throw new \Exception('货号无法匹配',500);
            }

            $express = $this->rhawnOrdersService->getExpress(
                $orderItems['weight'],$requestParams['so_ca_province'],$orderItems['total'],$customer['cus_free_express'],$customer['cus_level']
            );

            $order = $this->rhawnOrdersService->rhawnSorderRepository->getSorderFromOrderCusPo($requestParams['so_cus_po']);
            if($order){
                throw new \Exception('不能重复创建新订单!',500);
            }

            $data = [];
            $data['sorders']['cus_id'] = $customer['cus_id'];
            $data['sorders']['so_cus_po'] = $requestParams['so_cus_po'];
            $data['sorders']['so_ca_name'] = $requestParams['so_ca_name'];
            $data['sorders']['so_ca_mobile'] = $requestParams['so_ca_mobile'];
            $data['sorders']['so_ca_phone'] = !isset($requestParams['so_ca_phone']) ? '' : $requestParams['so_ca_phone'];
            $data['sorders']['so_ca_province'] = $requestParams['so_ca_province'];
            $data['sorders']['so_ca_city'] = $requestParams['so_ca_city'];
            $data['sorders']['so_ca_county'] = $requestParams['so_ca_county'];
            $data['sorders']['so_ca_street'] = $requestParams['so_ca_street'];

            //得到收票地址
            $rhawnCustomerRepository = app(RhawnCustomerRepositoryEloquent::class);
            $cusiaddrs_arr = $rhawnCustomerRepository->getCustomerAddressByCusCode($customer['cus_no']);
            $cusinvoice_arr = $rhawnCustomerRepository->getCustomerInvoiceByCusCode($customer['cus_no']);

            if(!$cusiaddrs_arr){
               throw new \Exception('请至会员中心设置收票地址',500);
            }
            if(!$cusinvoice_arr){
                throw new \Exception('请至会员中心设置发票信息',500);
            }

            $cusiaddrs_arr = current($cusiaddrs_arr);
            $cusinvoice_arr = current($cusinvoice_arr);

            $data['sorders']['so_cia_name'] = $cusiaddrs_arr['cia_name'];
            $data['sorders']['so_cia_mobile'] = $cusiaddrs_arr['cia_mobile'];
            $data['sorders']['so_cia_phone'] = $cusiaddrs_arr['cia_phone'];
            $data['sorders']['so_cia_province'] = $cusiaddrs_arr['cia_province'];
            $data['sorders']['so_cia_city'] = $cusiaddrs_arr['cia_city'];
            $data['sorders']['so_cia_county'] = $cusiaddrs_arr['cia_county'];
            $data['sorders']['so_cia_street'] = $cusiaddrs_arr['cia_street'];

            $data['sorders']['so_cia_name'] = $cusiaddrs_arr['cia_name'];
            $data['sorders']['so_ci_type'] = $cusinvoice_arr['ci_type'];
            $data['sorders']['so_ci_title'] = $cusinvoice_arr['ci_title'];
            $data['sorders']['so_ci_vatno'] = $cusinvoice_arr['ci_vatno'];
            $data['sorders']['so_ci_bank'] = $cusinvoice_arr['ci_bank'];
            $data['sorders']['so_ci_bknum'] = $cusinvoice_arr['ci_bknum'];
            $data['sorders']['so_ci_addr'] = $cusinvoice_arr['ci_addr'];
            $data['sorders']['so_ci_phone'] = $cusinvoice_arr['ci_phone'];

            if(!isset($requestParams['so_note'])){
                $requestParams['so_note'] = '';
            }
            $data['sorders']['so_note'] = $requestParams['so_note'];
            $data['sorders']['so_send_note'] = $customer['cus_send_note'];
            $data['sorders']['so_if_wx'] = 0;
            $data['sorders']['so_if_api'] = 1;
            $data['sorders']['so_ci_method'] = 1;
            $data['sorders']['so_total'] = $orderItems['total'] + $express;
            $data['express'] = $express;
            $data['v_id'] = '';
            $data['soitems'] = [];
            foreach($orderItems['rows'] as $k => $v){
                $soitem = [];
                $soitem['p_id'] = $v['product_info']['p_id'];
                $soitem['si_price'] = $v['product_info']['p_price'];
                $soitem['si_discount'] = $v['product_info']['p_discount'];
                $soitem['si_num'] = $v['num'];
                $soitem['si_amount'] = $v['product_info']['p_discount'] * $v['num'];
                $soitem['si_p_tod'] = $v['product_info']['p_tod'];
                $soitem['si_vamount'] = 0;
                if(isset($v['si_cus_note'])){
                    $soitem['si_cus_note'] = $v['si_cus_note'];
                }
                if(isset($v['si_molbase_pog'])){
                    $soitem['si_molbase_pog'] = $v['si_molbase_pog'];
                }
                array_push($data['soitems'],$soitem);
            }

            $orderId = $this->rhawnOrdersService->createOrders($data);
            if($orderId){
                $orderDetail = $this->rhawnOrdersService->getCustomerOrderItemsByOrderId($customer['cus_id'],$orderId);
                $orderDetail = app(OrderDetailTransformer::class)->transform([$orderDetail]);
                return current($orderDetail);
            }
            return null;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':createNewCustomerOrders','error');
            throw $exception;
        }
    }

    /**
     * 取消客户订单
     * @param $requestParams
     */
    public function cancelCustomerOrder($requestParams)
    {
        try{
            $customer = $this->rhawnCustomerService->checkCustomerExist($requestParams['customer_code']);
            $order = $this->rhawnOrdersService->getSordersByOrderNo($requestParams['order_number']);
            if(!$order){
                throw new \Exception('订单编号不存在',500);
            }
            if($order['so_review_status'] != 0){
                throw new \Exception('订单不是未审核状态，不能取消！',500);
            }
            if($order['so_pay_status'] != 0){
                throw new \Exception('订单不是未付款状态，不能取消！',500);
            }

            return $this->rhawnOrdersService->cancelCustomerOrderByOrderId($customer['cus_id'],$order['so_id']);

        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':cancelCustomerOrder','error');
            throw $exception;
        }
    }

    public function getOrderDispatchByOrderNumber($requestParams)
    {
        try{
            $customer = $this->rhawnCustomerService->checkCustomerExist($requestParams['customer_code']);
            $order = $this->rhawnOrdersService->getSordersByOrderNo($requestParams['order_number']);
            if(!$order){
                throw new \Exception('订单编号不存在',500);
            }
            if($order['cus_id'] != $customer['cus_id']){
                throw new \Exception('该订单你无权操作',500);
            }
            $dpdetail = $this->rhawnOrdersService->getOrderDispatchDetail($order['so_no']);
            if($dpdetail){
                $dpdetail = app(OrdersDispatchTransformer::class)->transform($dpdetail);
            }
            return $dpdetail;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':getOrderDispatchByOrderNumber','error');
            throw $exception;
        }
    }

}
