<?php

namespace App\Services\Api;

use App\Repositories\Transformers\Rhawn\ProductDetailTransformer;
use App\Repositories\Transformers\Rhawn\ProductsTransformer;
use App\Rhawn\Services\RhawnCustomerService;
use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;

class RhawnProductsService
{
    public function __construct(\App\Rhawn\Services\RhawnProductService $rhawnProductService)
    {
        $this->rhawnProductService = $rhawnProductService;
    }

    public function getAllProducts($requestParams)
    {
        $customer = $this->checkCustomerExist($requestParams['customer_code']);

        $offset = !isset($requestParams['page_size']) || empty($requestParams['page_size']) ? 2000 : $requestParams['page_size'];
        if($offset > 100){
            $offset = 100;
        }
        $pageNo = !isset($requestParams['page_no']) || empty($requestParams['page_no']) ? 1 : $requestParams['page_no'];
        $limit = $pageNo == 1 ? 0 : $pageNo * $offset;

        try{
            $where = [];
            $products = $this->rhawnProductService->getProductsListWithPromotions($offset,$limit,$where);
            $productsTotal = 0;
            if($products){
                $products = app(ProductsTransformer::class)->transform($products);
                $productsTotal = $this->rhawnProductService->rhawnProductRepository->count($where);
            }

            $dataReturn = [];
            $dataReturn['data'] = $products;
            $dataReturn['total_page'] = ceil($productsTotal / $offset);
            $dataReturn['page_no'] = $pageNo;

            return $dataReturn;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':cancelCustomerOrder','error');
            throw $exception;
        }
    }

    public function getProductDetail($requestParams)
    {
        $customer = $this->checkCustomerExist($requestParams['customer_code']);
        try{
            $products = $this->rhawnProductService->getProductDetailWithPromotions($requestParams['product_code'],$customer['cus_no']);
            if($products){
                $products = app(ProductDetailTransformer::class)->transform($products);
            }
            return $products;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':cancelCustomerOrder','error');
            throw $exception;
        }
    }

    public function getProductByCas($requestParams)
    {
        $customer = $this->checkCustomerExist($requestParams['customer_code']);
        try{
            $products = $this->rhawnProductService->getProductsWithPromotionsByCas($requestParams['cas']);
            if($products){
                $products = app(ProductsTransformer::class)->transform([$products],'bycas');
                $products = current($products);
            }
            return $products;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':cancelCustomerOrder','error');
            throw $exception;
        }
    }


    /**
     * 检查客户信息是否存在
     * @param $cusCode
     * @return mixed
     * @throws \Exception
     */
    private function checkCustomerExist($cusCode)
    {
        //查询用户是否存在
        $rhawnCustomerService = app(RhawnCustomerService::class);
        $customer = $rhawnCustomerService->getRhawnCustomerThroughtCusCode($cusCode);
        if(!$customer){
            throw new \Exception('客户编号为:['.$cusCode.']的用户不存在!',500);
        }
        return $customer;
    }

}
