<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\ThirdPlatform;

use App\Jobs\queue\QueueJob;
use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Services\Kafka\KafkaService;
use App\Services\PlatformDataEntriesService;
use App\Support\Facades\SimpleKafka;

abstract class PlatformAbstractService
{
    protected $thirdApiPlatformRepository;
    protected $platformName;
    protected $platformInfo;

    public function __construct(ThirdApiPlatformRepository $thirdApiPlatformRepository)
    {
        $this->thirdApiPlatformRepository = $thirdApiPlatformRepository;
        $this->dataEntriesService = app(PlatformDataEntriesService::class);
        //app(ThirdApiPlatformRepository::class)->getPlatformInfoByPlatformName($this->platformName);
    }

    protected function setPlatformName($platformName){
        $this->platformName = $platformName;
    }

    public function getPlatformInfo($key = null)
    {
        if($this->platformName == ''){
            return null;
        }

        if($this->platformInfo == null){
            $platform = $this->thirdApiPlatformRepository->getPlatformInfoByPlatformName($this->platformName);
            if(!$platform){
                return null;
            }
            $platform['platform_params'] = json_decode($platform['platform_params'], true);
            $this->platformInfo = $platform;
        }

        if($key == null){
            return $this->platformInfo;
        }elseif (isset($this->platformInfo[$key])) {
            return $this->platformInfo[$key];
        }

        return null;
    }

    protected function batchUpdateProducts($params = null)
    {
    }

    protected function batchUpdateApi($apiParams)
    {
    }

    /**
     * @对平台状态进行检查
     * @return bool
     * @throws \Exception
     */
    public function checkPlatformStatus(){
        if(!$this->platformInfo){
            throw new \Exception('第三方平台信息无法获取!',500);
        }
        if($this->platformInfo['platform_status'] != 1){
            throw new \Exception('当前平台处于关闭状态，无法使用');
        }
        return true;
    }

    /**
     * @异常处理后续
     * @实现方式将失败队列插入失败队列数据库里
     * @param $failQueueContent
     */
    public function throwableAfter($failQueueContent)
    {
        $service = app(KafkaService::class);
        $service->storeFailQueue($failQueueContent);
    }

    public function getPlatformDataEntries($dataKey,$returnKey = null)
    {
        $dataEntries = $this->dataEntriesService->getEntriesValues(
            $this->platformInfo['id'],$dataKey
        );
        if(!$dataEntries){
            return null;
        }
        $dataEntries = current($dataEntries);
        if(!is_null($returnKey) && $dataEntries[$returnKey]){
            return json_decode($dataEntries[$returnKey],true);
        }
        return $dataEntries;
    }

    public function storePlatformDataEntries($dataKey, $dataValues)
    {
        return $this->dataEntriesService->storeEntries($this->getPlatformInfo('id'),$dataKey,$dataValues);
    }

    public function removePlatformDataEntries($dataKey)
    {
        return $this->dataEntriesService->removeEntriesValues($this->getPlatformInfo('id'),$dataKey);
    }

    public function pushQueue($pushContent, $queueName)
    {
        if(env('QUEUE_CONNECTION') == 'database'){
            app('Illuminate\Contracts\Bus\Dispatcher')->dispatch(
                (new QueueJob($pushContent))->onQueue($queueName)
            );
        }else{
            SimpleKafka::produerSend($pushContent,$queueName);
        }
    }
}
